CalendarDatePicker2Config class

Implementers

Constructors

CalendarDatePicker2Config({CalendarDatePicker2Type? calendarType, DateTime? firstDate, DateTime? lastDate, DateTime? currentDate, DatePickerMode? calendarViewMode, List<String>? weekdayLabels, TextStyle? weekdayLabelTextStyle, int? firstDayOfWeek, double? controlsHeight, Widget? lastMonthIcon, Widget? nextMonthIcon, TextStyle? controlsTextStyle, TextStyle? dayTextStyle, TextStyle? selectedDayTextStyle, Color? selectedDayHighlightColor, TextStyle? disabledDayTextStyle, TextStyle? todayTextStyle, TextStyle? yearTextStyle, TextStyle? selectedYearTextStyle, BorderRadius? dayBorderRadius, BorderRadius? yearBorderRadius, SelectableDayPredicate? selectableDayPredicate, CalendarDayTextStylePredicate? dayTextStylePredicate, CalendarDayBuilder? dayBuilder, bool? disableYearPicker, bool? centerAlignModePickerButton, Widget? customModePickerButtonIcon})

Properties

calendarType CalendarDatePicker2Type
The enabled date picker mode
final
calendarViewMode DatePickerMode
The initially displayed view of the calendar picker.
final
centerAlignModePickerButton bool?
Flag to centralize year and month text label in controls
final
controlsHeight double?
Custom height for calendar control toggle's height
final
controlsTextStyle TextStyle?
Custom text style for calendar mode toggle control
final
currentDate DateTime
The DateTime representing today. It will be highlighted in the day grid.
final
customModePickerButtonIcon Widget?
Custom icon for the mode picker button icon
final
dayBorderRadius BorderRadius?
Custom border radius for day indicator
final
dayBuilder CalendarDayBuilder?
Function to build customizable day widget
final
dayTextStyle TextStyle?
Custom text style for all calendar days
final
dayTextStylePredicate CalendarDayTextStylePredicate?
Function to provide full control over calendar days text style
final
disabledDayTextStyle TextStyle?
Custom text style for disabled calendar day(s)
final
disableYearPicker bool?
Flag to disable year picker and hide the mode toggle button icon
final
firstDate DateTime
The earliest allowable DateTime that the user can select.
final
firstDayOfWeek int?
Index of the first day of week, where 0 points to Sunday, and 6 points to Saturday.
final
hashCode int
The hash code for this object.
no setterinherited
lastDate DateTime
The latest allowable DateTime that the user can select.
final
lastMonthIcon Widget?
Custom icon for last month button control
final
nextMonthIcon Widget?
Custom icon for next month button control
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectableDayPredicate SelectableDayPredicate?
Function to provide full control over which dates in the calendar can be selected.
final
selectedDayHighlightColor Color?
The highlight color for selected day(s)
final
selectedDayTextStyle TextStyle?
Custom text style for selected calendar day(s)
final
selectedYearTextStyle TextStyle?
final
todayTextStyle TextStyle?
Custom text style for today
final
weekdayLabels List<String>?
Custom weekday labels for the current locale, MUST starts from Sunday Examples:
final
weekdayLabelTextStyle TextStyle?
Custom text style for weekday labels
final
yearBorderRadius BorderRadius?
Custom border radius for year indicator
final
yearTextStyle TextStyle?
final

Methods

copyWith({CalendarDatePicker2Type? calendarType, DateTime? firstDate, DateTime? lastDate, DateTime? currentDate, DatePickerMode? calendarViewMode, List<String>? weekdayLabels, TextStyle? weekdayLabelTextStyle, int? firstDayOfWeek, double? controlsHeight, Widget? lastMonthIcon, Widget? nextMonthIcon, TextStyle? controlsTextStyle, TextStyle? dayTextStyle, TextStyle? selectedDayTextStyle, Color? selectedDayHighlightColor, TextStyle? disabledDayTextStyle, TextStyle? todayTextStyle, TextStyle? yearTextStyle, TextStyle? selectedYearTextStyle, BorderRadius? dayBorderRadius, BorderRadius? yearBorderRadius, SelectableDayPredicate? selectableDayPredicate, CalendarDayTextStylePredicate? dayTextStylePredicate, CalendarDayBuilder? dayBuilder, bool? disableYearPicker, bool? centerAlignModePickerButton, Widget? customModePickerButtonIcon}) CalendarDatePicker2Config
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited