CalendarDatePicker2WithActionButtonsConfig class
- Inheritance
-
- Object
- CalendarDatePicker2Config
- CalendarDatePicker2WithActionButtonsConfig
Constructors
-
CalendarDatePicker2WithActionButtonsConfig({CalendarDatePicker2Type? calendarType, DateTime? firstDate, DateTime? lastDate, DateTime? currentDate, DatePickerMode? calendarViewMode, List<
String> ? weekdayLabels, TextStyle? weekdayLabelTextStyle, int? firstDayOfWeek, double? controlsHeight, Widget? lastMonthIcon, Widget? nextMonthIcon, TextStyle? controlsTextStyle, TextStyle? dayTextStyle, TextStyle? selectedDayTextStyle, Color? selectedDayHighlightColor, TextStyle? disabledDayTextStyle, TextStyle? todayTextStyle, TextStyle? yearTextStyle, TextStyle? selectedYearTextStyle, BorderRadius? dayBorderRadius, BorderRadius? yearBorderRadius, SelectableDayPredicate? selectableDayPredicate, CalendarDayTextStylePredicate? dayTextStylePredicate, CalendarDayBuilder? dayBuilder, bool? disableYearPicker, bool? centerAlignModePickerButton, Widget? customModePickerButtonIcon, double? gapBetweenCalendarAndButtons, TextStyle? cancelButtonTextStyle, Widget? cancelButton, TextStyle? okButtonTextStyle, Widget? okButton, bool? openedFromDialog, bool? closeDialogOnCancelTapped, bool? closeDialogOnOkTapped, EdgeInsets? buttonPadding})
Properties
-
Custom wrapping padding for Ok & Cancel buttons
final
- calendarType → CalendarDatePicker2Type
-
The enabled date picker mode
finalinherited
- calendarViewMode → DatePickerMode
-
The initially displayed view of the calendar picker.
finalinherited
- cancelButton → Widget?
-
Custom cancel button
final
- cancelButtonTextStyle → TextStyle?
-
Text style for cancel button
final
- centerAlignModePickerButton → bool?
-
Flag to centralize year and month text label in controls
finalinherited
- closeDialogOnCancelTapped → bool?
-
If the dialog should be closed when user taps the CANCEL button
final
- closeDialogOnOkTapped → bool?
-
If the dialog should be closed when user taps the OK button
final
- controlsHeight → double?
-
Custom height for calendar control toggle's height
finalinherited
- controlsTextStyle → TextStyle?
-
Custom text style for calendar mode toggle control
finalinherited
- currentDate → DateTime
-
The DateTime representing today. It will be highlighted in the day grid.
finalinherited
- customModePickerButtonIcon → Widget?
-
Custom icon for the mode picker button icon
finalinherited
- dayBorderRadius → BorderRadius?
-
Custom border radius for day indicator
finalinherited
- dayBuilder → CalendarDayBuilder?
-
Function to build customizable day widget
finalinherited
- dayTextStyle → TextStyle?
-
Custom text style for all calendar days
finalinherited
- dayTextStylePredicate → CalendarDayTextStylePredicate?
-
Function to provide full control over calendar days text style
finalinherited
- disabledDayTextStyle → TextStyle?
-
Custom text style for disabled calendar day(s)
finalinherited
- disableYearPicker → bool?
-
Flag to disable year picker and hide the mode toggle button icon
finalinherited
- firstDate → DateTime
-
The earliest allowable DateTime that the user can select.
finalinherited
- firstDayOfWeek → int?
-
Index of the first day of week, where 0 points to Sunday, and 6 points to Saturday.
finalinherited
- gapBetweenCalendarAndButtons → double?
-
The gap between calendar and action buttons
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastDate → DateTime
-
The latest allowable DateTime that the user can select.
finalinherited
- lastMonthIcon → Widget?
-
Custom icon for last month button control
finalinherited
- nextMonthIcon → Widget?
-
Custom icon for next month button control
finalinherited
- okButton → Widget?
-
Custom ok button
final
- okButtonTextStyle → TextStyle?
-
Text style for ok button
final
- openedFromDialog → bool?
-
Is the calendar opened from dialog
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectableDayPredicate → SelectableDayPredicate?
-
Function to provide full control over which dates in the calendar can be selected.
finalinherited
- selectedDayHighlightColor → Color?
-
The highlight color for selected day(s)
finalinherited
- selectedDayTextStyle → TextStyle?
-
Custom text style for selected calendar day(s)
finalinherited
- selectedYearTextStyle → TextStyle?
-
finalinherited
- todayTextStyle → TextStyle?
-
Custom text style for today
finalinherited
-
weekdayLabels
→ List<
String> ? -
Custom weekday labels for the current locale, MUST starts from Sunday
Examples:
finalinherited
- weekdayLabelTextStyle → TextStyle?
-
Custom text style for weekday labels
finalinherited
- yearBorderRadius → BorderRadius?
-
Custom border radius for year indicator
finalinherited
- yearTextStyle → TextStyle?
-
finalinherited
Methods
-
copyWith(
{CalendarDatePicker2Type? calendarType, DateTime? firstDate, DateTime? lastDate, DateTime? currentDate, DatePickerMode? calendarViewMode, List< String> ? weekdayLabels, TextStyle? weekdayLabelTextStyle, int? firstDayOfWeek, double? controlsHeight, Widget? lastMonthIcon, Widget? nextMonthIcon, TextStyle? controlsTextStyle, TextStyle? dayTextStyle, TextStyle? selectedDayTextStyle, Color? selectedDayHighlightColor, TextStyle? disabledDayTextStyle, TextStyle? todayTextStyle, TextStyle? yearTextStyle, TextStyle? selectedYearTextStyle, double? gapBetweenCalendarAndButtons, TextStyle? cancelButtonTextStyle, Widget? cancelButton, TextStyle? okButtonTextStyle, Widget? okButton, bool? openedFromDialog, bool? closeDialogOnCancelTapped, bool? closeDialogOnOkTapped, BorderRadius? dayBorderRadius, BorderRadius? yearBorderRadius, SelectableDayPredicate? selectableDayPredicate, CalendarDayTextStylePredicate? dayTextStylePredicate, CalendarDayBuilder? dayBuilder, bool? disableYearPicker, bool? centerAlignModePickerButton, Widget? customModePickerButtonIcon, EdgeInsets? buttonPadding}) → CalendarDatePicker2WithActionButtonsConfig -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited