TodayDrawerSection class

Constructors

TodayDrawerSection({String? title, String? content, Widget? widgetContent, bool hasBottomDivider = false})
const

Properties

content String?
final
hasBottomDivider bool
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
final
widgetContent Widget?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited