TodayGroup class

Inheritance

Constructors

TodayGroup({Key? key, TodayGroupType type = TodayGroupType.input, List<TodayInput>? inputs, List<TodayDropdown>? selects, TodayDropdown selectSample()?, String? label, String? description, bool disabled = false, TodayInput onInputAdded()?, void onInputRemoved(String uuid)?, TodayDropdown onSelectAdded()?, void onSelectRemoved(String uuid)?})
const

Properties

description String?
final
disabled bool
final
hashCode int
The hash code for this object.
no setterinherited
inputs List<TodayInput>?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String?
final
onInputAdded TodayInput Function()?
final
onInputRemoved → void Function(String uuid)?
final
onSelectAdded TodayDropdown Function()?
final
onSelectRemoved → void Function(String uuid)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selects List<TodayDropdown>?
final
selectSample TodayDropdown Function()?
final
type TodayGroupType
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<TodayGroup>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited