TodayPage class

Inheritance

Constructors

TodayPage({Key? key, required String title, String? description, List<TodayBadge>? badges, List<TodayButton>? primaryActions, List<TodayLink>? secondaryActions, List<TodayDropdown>? tertiaryActions, TodayTab? tab, TodayBreadcrumb? breadcrumb, bool useDivider = true})
const

Properties

badges List<TodayBadge>?
final
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
primaryActions List<TodayButton>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryActions List<TodayLink>?
final
tab TodayTab?
final
tertiaryActions List<TodayDropdown>?
final
title String
final
useDivider bool
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<TodayPage>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited