TodayTableColumn class
Constructors
- TodayTableColumn({required String label, TextAlign align = TextAlign.left, double? width, bool selectable = false, TodayCheckboxValue selectableValue = TodayCheckboxValue.unchecked, bool selected = false, bool isMore = false, Widget? showcase, dynamic onChanged(TodayCheckboxValue value)?})
-
const
Properties
- align → TextAlign
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isMore → bool
-
final
- label → String
-
final
- onChanged → dynamic Function(TodayCheckboxValue value)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectable → bool
-
final
- selectableValue → TodayCheckboxValue
-
final
- selected → bool
-
final
- showcase → Widget?
-
final
- width → double?
-
final
Methods
-
column(
) → DataColumn -
getColumnContainer(
) → Widget -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited