TodayTableRow class

Constructors

TodayTableRow({required List<TodayTableCell> cells, bool selected = false, bool disabled = false, bool footer = false, bool isGroup = false, List<TodayTableRow> children = const [], dynamic onChanged(TodayCheckboxValue value)?, dynamic onSelectChanged(bool? value)?})
const

Properties

cells List<TodayTableCell>
final
children List<TodayTableRow>
final
disabled bool
final
final
hashCode int
The hash code for this object.
no setterinherited
isGroup bool
final
onChanged → dynamic Function(TodayCheckboxValue value)?
final
onSelectChanged → dynamic Function(bool? value)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected bool
final

Methods

getPadding({required bool toLeft, required TodayTableCellType type, bool large = false, bool isChild = false}) EdgeInsets
groupCell({required TodayTableCell cell, required bool isCollapsed, bool headerCell = false, double? width}) Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
row({bool large = false, List<double?>? widths, bool selectable = false, bool isCollapsed = false, bool isLastChild = false, Function? onSelected}) DataRow
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited