TodayToast class

Constructors

TodayToast()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

baseToast({GlobalKey<FlushbarState<Object?>>? key, required Widget title, Widget? description, required Widget icon, Function? onUndo, String? undoText, EdgeInsets? margin, required Color backgroundColor, int? duration, bool isDismissible = true}) → Flushbar
error({required String title, String? description, EdgeInsets? margin}) → Flushbar
loading({required BuildContext context, required String title, required Widget icon, String? description, Function? onUndo, String? undoText, int? duration}) GlobalKey<FlushbarState<Object?>>
success({required String title, String? description, Function? onUndo, String? undoText, EdgeInsets? margin}) → Flushbar