TodayTopBar class

Inheritance

Constructors

TodayTopBar({Key? key, TodayTopBarStyle style = TodayTopBarStyle.product, String? userFullName, String? placeholder, dynamic onSubmitted(String)?, dynamic onClickUserMenu()?, String? contextualImage, TodaySvgIcon? contextualIcon, Function? onTapContextualIcon, String? contextualTitle, bool showProgress = false, double currentProgress = 0, double progressBarWidth = 386, TodayContextualBarStatus saveStatus = TodayContextualBarStatus.hidden, Widget? primaryAction, Widget? secondaryAction, Color bgColor = Colors.white, Color borderColor = const Color.fromRGBO(39, 39, 42, 0.06), EdgeInsetsGeometry? padding, bool invisible = false})
const

Properties

bgColor Color
final
borderColor Color
final
contextualIcon TodaySvgIcon?
final
contextualImage String?
final
contextualTitle String?
final
currentProgress double
final
hashCode int
The hash code for this object.
no setterinherited
invisible bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onClickUserMenu → dynamic Function()?
final
onSubmitted → dynamic Function(String)?
final
onTapContextualIcon Function?
final
padding EdgeInsetsGeometry?
final
placeholder String?
final
primaryAction Widget?
final
progressBarWidth double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saveStatus TodayContextualBarStatus
final
secondaryAction Widget?
final
showProgress bool
final
style TodayTopBarStyle
final
userFullName String?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<TodayTopBar>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited