TodaySurfaceColor enum
Today's surface colors
Values
- transparent → const TodaySurfaceColor
-
Transparent color or rgba(255, 255, 255, 0)
const TodaySurfaceColor(Color.fromRGBO(255, 255, 255, 0)) - white → const TodaySurfaceColor
-
Color #FFFFFF or rgba(255, 255, 255, 1)
const TodaySurfaceColor(Color.fromRGBO(255, 255, 255, 1)) - frenchGray → const TodaySurfaceColor
-
Color #C7D1DB or rgba(199, 209, 219, 1)
const TodaySurfaceColor(Color.fromRGBO(199, 209, 219, 1)) - platinum → const TodaySurfaceColor
-
Color #E3E3E3 or rgba(227, 227, 227, 1)
const TodaySurfaceColor(Color.fromRGBO(227, 227, 227, 1)) - silver → const TodaySurfaceColor
-
Color #A3A3A3 or rgba(163, 163, 163, 1)
const TodaySurfaceColor(Color.fromRGBO(163, 163, 163, 1)) - gunmetal → const TodaySurfaceColor
-
Color #21272C or rgba(33, 39, 44, 1)
const TodaySurfaceColor(Color.fromRGBO(33, 39, 44, 1)) - eerieBlack → const TodaySurfaceColor
-
Color #161A1D or rgba(22, 26, 29, 1)
const TodaySurfaceColor(Color.fromRGBO(22, 26, 29, 1)) - eerieBlackAlt → const TodaySurfaceColor
-
Color #1D2125 or rgba(29, 33, 37, 1)
const TodaySurfaceColor(Color.fromRGBO(29, 33, 37, 1)) - tropicalIndigo → const TodaySurfaceColor
-
Color #7D82FF or rgba(125, 130, 255, 1)
const TodaySurfaceColor(Color.fromRGBO(125, 130, 255, 1)) - salmonPink → const TodaySurfaceColor
-
Color #F58291 or rgba(245, 130, 145, 1)
const TodaySurfaceColor(Color.fromRGBO(245, 130, 145, 1)) - coral → const TodaySurfaceColor
-
Color #F08057 or rgba(240, 128, 87, 1)
const TodaySurfaceColor(Color.fromRGBO(240, 128, 87, 1)) - kellyGreen → const TodaySurfaceColor
-
Color #51B639 or rgba(81, 182, 57, 1)
const TodaySurfaceColor(Color.fromRGBO(81, 182, 57, 1)) - robinEggBlue → const TodaySurfaceColor
-
Color #03CECE or rgba(3, 206, 206, 1)
const TodaySurfaceColor(Color.fromRGBO(3, 206, 206, 1)) - celticBlue → const TodaySurfaceColor
-
Color #1B75DD or rgba(27, 117, 221, 1)
const TodaySurfaceColor(Color.fromRGBO(27, 117, 221, 1))
Properties
- color → Color
-
Color from TodayTextColor
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
TodaySurfaceColor> - A constant List of the values in this enum, in order of their declaration.