TodaySvgBaseSize enum

Inheritance
Available extensions

Values

base16 → const TodaySvgBaseSize
base18 → const TodaySvgBaseSize
base20 → const TodaySvgBaseSize
base22 → const TodaySvgBaseSize
base24 → const TodaySvgBaseSize
base26 → const TodaySvgBaseSize
base28 → const TodaySvgBaseSize
base30 → const TodaySvgBaseSize
base32 → const TodaySvgBaseSize

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int

Available on TodaySvgBaseSize, provided by the TodaySvgBaseSizeExtension extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TodaySvgBaseSize>
A constant List of the values in this enum, in order of their declaration.