TodayContainer class
Container with Flex built with Today's configuration
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- TodayContainer
Constructors
-
TodayContainer({Key? key, double? width, double? height, EdgeInsetsGeometry margin = const EdgeInsets.all(0), EdgeInsetsGeometry padding = const EdgeInsets.all(0), TodaySurfaceColor color = TodaySurfaceColor.transparent, Axis direction = Axis.vertical, MainAxisAlignment justifyContent = MainAxisAlignment.start, CrossAxisAlignment alignItems = CrossAxisAlignment.start, BoxConstraints? constraints, BoxBorder? border, TodayRadius? borderRadius, List<
BoxShadow> boxShadow = const <BoxShadow>[], List<Widget> children = const <Widget>[]}) -
const
Properties
- alignItems → CrossAxisAlignment
-
How the container will be aligned in the cross axis.
final
- border → BoxBorder?
-
Border of the container.
final
- borderRadius → TodayRadius?
-
How the container border radius will be handled.
final
-
boxShadow
→ List<
BoxShadow> -
List of BoxShadow for the container.
final
-
children
→ List<
Widget> -
List of children widgets.
final
- color → TodaySurfaceColor
-
How the container will be colored.
final
- constraints → BoxConstraints?
-
How the container constraints will be handled.
final
- direction → Axis
-
How the container will be orientated.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
Height of the container.
final
- justifyContent → MainAxisAlignment
-
How the container will be aligned in the main axis.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- margin → EdgeInsetsGeometry
-
How the container margin will be handled.
final
- padding → EdgeInsetsGeometry
-
How the container margin will be handled.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → double?
-
Width of the container.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited