alignItems property
How the container will be aligned in the cross axis.
If this is null CrossAxisAlignment.start will be used.
Implementation
final CrossAxisAlignment alignItems;
How the container will be aligned in the cross axis.
If this is null CrossAxisAlignment.start will be used.
final CrossAxisAlignment alignItems;