justifyContent property
How the container will be aligned in the main axis.
If this is null MainAxisAlignment.start will be used.
Implementation
final MainAxisAlignment justifyContent;
How the container will be aligned in the main axis.
If this is null MainAxisAlignment.start will be used.
final MainAxisAlignment justifyContent;