TodayText class
RichText built with Today's configuration
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- TodayText
Constructors
- TodayText(String content, {Key? key, TodayTextStyle? style = TodayTextStyle.tdsFontRegular, TodayTextColor? color = TodayTextColor.eerieBlack, Color? rawColor, TextAlign? textAlign, TextOverflow? overflow, Color? selectionColor, TextDecoration? decoration, TextDecorationStyle? decorationStyle, TextBaseline? textBaseline})
-
const
Properties
- color → TodayTextColor?
-
How the text will be colored.
final
- content → String?
-
The text to display.
final
- decoration → TextDecoration?
-
final
- decorationStyle → TextDecorationStyle?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- overflow → TextOverflow?
-
How visual overflow should be handled.
final
- rawColor → Color?
-
How the text will be colored with raw color.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectionColor → Color?
-
The color to use when painting the selection.
final
- style → TodayTextStyle?
-
How the text will be styled.
final
- textAlign → TextAlign?
-
How the text should be aligned horizontally.
final
- textBaseline → TextBaseline?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited