overflow property
How visual overflow should be handled.
If this is null the value from the nearest DefaultTextStyle
ancestor will be used, otherwise TextOverflow.overflow will be used.
Implementation
final TextOverflow? overflow;
How visual overflow should be handled.
If this is null the value from the nearest DefaultTextStyle
ancestor will be used, otherwise TextOverflow.overflow will be used.
final TextOverflow? overflow;