textAlign property
How the text should be aligned horizontally.
If this is null the value from the nearest DefaultTextStyle ancestor will be used, otherwise TextAlign.start will be used.
Implementation
final TextAlign? textAlign;
How the text should be aligned horizontally.
If this is null the value from the nearest DefaultTextStyle ancestor will be used, otherwise TextAlign.start will be used.
final TextAlign? textAlign;