alignItems property
How the container will be aligned in the cross axis.
If this is null WrapCrossAlignment.start will be used.
Implementation
final WrapCrossAlignment alignItems;
How the container will be aligned in the cross axis.
If this is null WrapCrossAlignment.start will be used.
final WrapCrossAlignment alignItems;