justifyContent property
How the container will be aligned in the main axis.
If this is null WrapAlignment.start will be used.
Implementation
final WrapAlignment justifyContent;
How the container will be aligned in the main axis.
If this is null WrapAlignment.start will be used.
final WrapAlignment justifyContent;