TodayDropdown<T> class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- TodayDropdown
Constructors
-
TodayDropdown({Key? key, String? uuid, dynamic value, TodayDropdownStyle style = TodayDropdownStyle.extended, required List<
TodayDropdownItem> items, TodayDropdownTrigger trigger = TodayDropdownTrigger.button, String? label, String? optionalLabel, TodayIcon? icon, String? description, bool error = false, String? errorMessage, Color? placeholderColor, String placeholder = 'Select one...', List<TodayTag> ? tags, dynamic onChanged(TodayDropdownItem itemSelected)?, TodayDropdownPosition position = TodayDropdownPosition.left, bool searchable = false, String searchPlaceholder = 'Search...', bool disabled = false, bool showDescription = true, TodayDropdownButtonOverride? buttonOverride, TodaySvgIcon? buttonOverrideIcon, bool buttonOverrideIconOnly = false, TodayButtonIconDirection buttonIconDirectionOverride = TodayButtonIconDirection.left, Offset? offset, double? dropdownItemSize, bool noWrap = false, bool autoFocus = false, bool linkFocusStyle = false, bool emphasized = false, TodayDropdownLinkFocusStyle linkFocusStyleType = TodayDropdownLinkFocusStyle.link, Widget? customWidget, Widget? customIcon}) -
const
Properties
- autoFocus → bool
-
final
-
final
-
final
-
final
-
final
- customIcon → Widget?
-
final
- customWidget → Widget?
-
final
- description → String?
-
final
- disabled → bool
-
final
- dropdownItemSize → double?
-
final
- emphasized → bool
-
final
- error → bool
-
final
- errorMessage → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → TodayIcon?
-
final
-
items
→ List<
TodayDropdownItem> -
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- label → String?
-
final
- linkFocusStyle → bool
-
final
- linkFocusStyleType → TodayDropdownLinkFocusStyle
-
final
-
final
-
final
- noWrap → bool
-
final
- offset → Offset?
-
final
- onChanged → dynamic Function(TodayDropdownItem itemSelected)?
-
final
- optionalLabel → String?
-
final
- placeholder → String
-
final
- placeholderColor → Color?
-
final
- position → TodayDropdownPosition
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchable → bool
-
final
- searchPlaceholder → String
-
final
- showDescription → bool
-
final
- style → TodayDropdownStyle
-
final
-
final
- trigger → TodayDropdownTrigger
-
final
- uuid → String?
-
final
- value → dynamic
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< TodayDropdown> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited