TodayInput class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- TodayInput
Constructors
-
TodayInput({Key? key, String? uuid, String value = '', String? placeholder, String? label, String? optionalLabel, String? description, TodayLink? link, bool error = false, String? errorMessage, bool disabled = false, dynamic onSubmitted(String)?, dynamic onChanged(String)?, dynamic onTapOutside(String)?, TodayInputType type = TodayInputType.text, TodayInputPrefix? prefix, TodaySvgIcon? customPrefix, TodayInputSuffix? suffix, int? limit, bool innerInput = false, bool autofocus = false, bool transparent = false, bool overwriteValue = false, bool small = false, Iterable<
String> ? autofillHints}) -
const
Properties
-
autofillHints
→ Iterable<
String> ? -
final
- autofocus → bool
-
final
- customPrefix → TodaySvgIcon?
-
final
- description → String?
-
final
- disabled → bool
-
final
- error → bool
-
final
- errorMessage → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- innerInput → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- label → String?
-
final
- limit → int?
-
final
- link → TodayLink?
-
final
- onChanged → dynamic Function(String)?
-
final
- onSubmitted → dynamic Function(String)?
-
final
- onTapOutside → dynamic Function(String)?
-
final
- optionalLabel → String?
-
final
- overwriteValue → bool
-
final
- placeholder → String?
-
final
- prefix → TodayInputPrefix?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- small → bool
-
final
- suffix → TodayInputSuffix?
-
final
- transparent → bool
-
final
- type → TodayInputType
-
final
- uuid → String?
-
final
- value → String
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< TodayInput> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited