TodayModal class
Constructors
- TodayModal({String? title, String? description, TodayIcon? titleIcon, bool showHeader = true, bool hideHeaderLine = false, bool showClose = true, double? width, double? height, Widget? content, Widget? primaryAction, Widget? secondaryAction, TodayModalStyle style = TodayModalStyle.alert, TodayModalType type = TodayModalType.success, Function? onClose})
-
const
Properties
- content → Widget?
-
final
- description → String?
-
final
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
final
- hideHeaderLine → bool
-
final
- onClose → Function?
-
final
- primaryAction → Widget?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondaryAction → Widget?
-
final
- showClose → bool
-
final
-
final
- showHeader → bool
-
final
- style → TodayModalStyle
-
final
- title → String?
-
final
- titleIcon → TodayIcon?
-
final
- type → TodayModalType
-
final
- width → double?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
show(
BuildContext context) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited