TodayNavigationItem class
Constructors
Properties
- actionTooltip ↔ String?
-
getter/setter pair
-
children
↔ List<
TodayNavigationItem> ? -
getter/setter pair
- hasAction ↔ bool
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hovered ↔ bool
-
getter/setter pair
- icon ↔ TodaySvgIcon?
-
getter/setter pair
- label ↔ String
-
getter/setter pair
- onAction ↔ Function?
-
getter/setter pair
- onTap ↔ Function?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selected ↔ bool
-
getter/setter pair
Methods
-
hasChildren(
) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited