TodayProgressIndicatorItem class
Constructors
-
TodayProgressIndicatorItem({required String label, TodaySvgIcon? icon, TodayProgressIndicatorItemState state = TodayProgressIndicatorItemState.inactive, List<
TodayProgressIndicatorItem> ? subItems}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → TodaySvgIcon?
-
final
- label → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → TodayProgressIndicatorItemState
-
final
-
subItems
→ List<
TodayProgressIndicatorItem> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited