TodayRadioValue enum
Values
- unchecked → const TodayRadioValue
- checked → const TodayRadioValue
- one → const TodayRadioValue
- two → const TodayRadioValue
- three → const TodayRadioValue
- four → const TodayRadioValue
- five → const TodayRadioValue
- six → const TodayRadioValue
- seven → const TodayRadioValue
- eight → const TodayRadioValue
- nine → const TodayRadioValue
- ten → const TodayRadioValue
- eleven → const TodayRadioValue
- twelve → const TodayRadioValue
- thirteen → const TodayRadioValue
- fourteen → const TodayRadioValue
- fifteen → const TodayRadioValue
- sixteen → const TodayRadioValue
- seventeen → const TodayRadioValue
- eightteen → const TodayRadioValue
- nineteen → const TodayRadioValue
- twenty → const TodayRadioValue
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
TodayRadioValue> - A constant List of the values in this enum, in order of their declaration.