TodayTable class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- TodayTable
Constructors
-
TodayTable({Key? key, bool selectable = false, required List<
TodayTableColumn> columns, required List<TodayTableRow> rows, List<TodayTableColumn> ? fixedColumnsLeft, List<TodayTableRow> ? fixedRowsLeft, List<TodayTableColumn> ? fixedColumnsRight, List<TodayTableRow> ? fixedRowsRight, bool allSelected = false, TodayCheckboxValue selectableValue = TodayCheckboxValue.unchecked, dynamic onChanged(TodayCheckboxValue)?, dynamic onSearch(String? value)?, String? headerPlaceholder, TodayFilter? headerPrimaryFilter, Widget? headerPrimaryWidget, TodayButton? headerSecondaryButton, Widget? headerSecondaryWidget, Widget? headerSearchWidget, bool hideHeader = false, bool leftArrowEnabled = false, bool rightArrowEnabled = false, Function? leftArrowClick, Function? rightArrowClick, bool largeCells = false, String? emptyTitle, String? emptyDescription, Widget? emptyWidget, bool hoverEffects = false, bool loading = false, int? perPage, int currentPage = 1}) -
const
Properties
- allSelected → bool
-
final
-
columns
→ List<
TodayTableColumn> -
final
- currentPage → int
-
final
- emptyDescription → String?
-
final
- emptyTitle → String?
-
final
- emptyWidget → Widget?
-
final
-
fixedColumnsLeft
→ List<
TodayTableColumn> ? -
final
-
fixedColumnsRight
→ List<
TodayTableColumn> ? -
final
-
fixedRowsLeft
→ List<
TodayTableRow> ? -
final
-
fixedRowsRight
→ List<
TodayTableRow> ? -
final
-
final
-
final
-
final
-
final
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerPlaceholder → String?
-
final
- headerPrimaryFilter → TodayFilter?
-
final
- headerPrimaryWidget → Widget?
-
final
- headerSearchWidget → Widget?
-
final
- headerSecondaryButton → TodayButton?
-
final
- headerSecondaryWidget → Widget?
-
final
-
final
- hideHeader → bool
-
final
- hoverEffects → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- largeCells → bool
-
final
- leftArrowClick → Function?
-
final
- leftArrowEnabled → bool
-
final
- loading → bool
-
final
- onChanged → dynamic Function(TodayCheckboxValue)?
-
final
- onSearch → dynamic Function(String? value)?
-
final
- perPage → int?
-
final
- rightArrowClick → Function?
-
final
- rightArrowEnabled → bool
-
final
-
rows
→ List<
TodayTableRow> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectable → bool
-
final
- selectableValue → TodayCheckboxValue
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< TodayTable> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited