TodayTableCell class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- TodayTableCell
Constructors
-
TodayTableCell({Key? key, TodayTableCellType type = TodayTableCellType.text, Widget? icon, Widget? rightIcon, TodaySpacing iconSpacing = TodaySpacing.tdsSpace3, String? textContent, String? textDescription, bool shimmerDescription = false, Widget? customWidget, TodayLink? link, TodayInput? input, TodayDropdown? select, TodayCheckbox? checkbox, List<
TodayTag> ? tags, List<TodayBadge> ? badges, TodayColor textColor = TodayColor.labelPrimary, bool toLeft = false, bool emphasized = false, bool isChild = false, bool isLastChild = false, TextAlign align = TextAlign.left, List<TodayDropdownItem> ? dropdownItems, Alignment? cellAlignment, double? maxWidth, EdgeInsets padding = EdgeInsets.zero, bool shimmerTags = false}) -
const
Properties
- align → TextAlign
-
final
-
badges
→ List<
TodayBadge> ? -
final
- cellAlignment → Alignment?
-
final
- checkbox → TodayCheckbox?
-
final
- customWidget → Widget?
-
final
-
dropdownItems
→ List<
TodayDropdownItem> ? -
final
- emphasized → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Widget?
-
final
- iconSpacing → TodaySpacing
-
final
- input → TodayInput?
-
final
- isChild → bool
-
final
- isLastChild → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- link → TodayLink?
-
final
- maxWidth → double?
-
final
- padding → EdgeInsets
-
final
- rightIcon → Widget?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- select → TodayDropdown?
-
final
- shimmerDescription → bool
-
final
- shimmerTags → bool
-
final
-
final
- textColor → TodayColor
-
final
- textContent → String?
-
final
- textDescription → String?
-
final
- toLeft → bool
-
final
- type → TodayTableCellType
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< TodayTableCell> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited