TodayToast class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
baseToast({GlobalKey<FlushbarState<Object?>>? key, required Widget title, Widget? description, required Widget icon, Function? onUndo, required Color backgroundColor, int? duration, bool isDismissible = true})
→ Flushbar
-
-
error({required String title, String? description})
→ Flushbar
-
-
loading({required BuildContext context, required String title, required Widget icon, String? description, Function? onUndo})
→ GlobalKey<FlushbarState<Object?>>
-
-
success({required String title, String? description, Function? onUndo})
→ Flushbar
-