TodayShadow enum

Today's border radius

Inheritance
Available extensions

Values

tdsShadowXSmall → const TodayShadow

inset 0px -1px 0px rgba(39, 39, 42, 0.05), 0px 1px 3px rgba(39, 39, 42, 0.06)

const TodayShadow([BoxShadow(color: Color.fromRGBO(39, 39, 42, 0.05), blurRadius: 0, offset: Offset(0, -1), spreadRadius: 0), BoxShadow(color: Color.fromRGBO(39, 39, 42, 0.06), blurRadius: 3, offset: …
tdsShadowSmall → const TodayShadow

inset 0px -1px 0px rgba(39, 39, 42, 0.02), 0px 1px 1px rgba(39, 39, 42, 0.03), 0px 2px 4px rgba(39, 39, 42, 0.06)

const TodayShadow([BoxShadow(color: Color.fromRGBO(39, 39, 42, 0.02), blurRadius: 0, offset: Offset(0, -1), spreadRadius: 0), BoxShadow(color: Color.fromRGBO(39, 39, 42, 0.03), blurRadius: 1, offset: …
tdsShadowMedium → const TodayShadow

0px 4px 12px rgba(39, 39, 42, 0.06), 0px 1px 2px rgba(39, 39, 42, 0.01)

const TodayShadow([BoxShadow(color: Color.fromRGBO(39, 39, 42, 0.06), blurRadius: 12, offset: Offset(0, 4), spreadRadius: 0), BoxShadow(color: Color.fromRGBO(39, 39, 42, 0.01), blurRadius: 2, offset: …
tdsShadowLarge → const TodayShadow

0px 8px 16px rgba(39, 39, 42, 0.08), 0px 1px 1px rgba(39, 39, 42, 0.01)

const TodayShadow([BoxShadow(color: Color.fromRGBO(39, 39, 42, 0.08), blurRadius: 16, offset: Offset(0, 8), spreadRadius: 0), BoxShadow(color: Color.fromRGBO(39, 39, 42, 0.01), blurRadius: 1, offset: …
tdsShadowXLarge → const TodayShadow

0px 8px 32px rgba(39, 39, 42, 0.2),inset 0px -1px 0px rgba(39, 39, 42, 0.04), 0px 1px 1px rgba(39, 39, 42, 0.03), 0px 0px 0px rgba(39, 39, 42, 0.06)

const TodayShadow([BoxShadow(color: Color.fromRGBO(39, 39, 42, 0.2), blurRadius: 32, offset: Offset(0, 8), spreadRadius: 0), BoxShadow(color: Color.fromRGBO(39, 39, 42, 0.04), blurRadius: 0, offset: O…
tdsShadowInner → const TodayShadow

inset 0px -1px 0px rgba(39, 39, 42, 0.06)

const TodayShadow([BoxShadow(color: Color.fromRGBO(39, 39, 42, 0.06), blurRadius: 0, offset: Offset(0, -1), spreadRadius: 0)])

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shadows List<BoxShadow>
BorderRadiusGeometry from TodayRadius
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TodayShadow>
A constant List of the values in this enum, in order of their declaration.