TodaySpacing enum
Today's spacing
Values
- tdsSpace0 → const TodaySpacing
-
Spacing of 0px or 0rem
const TodaySpacing(0) - tdsSpace05 → const TodaySpacing
-
Spacing of 2px or 0.125rem
const TodaySpacing(2) - tdsSpace1 → const TodaySpacing
-
Spacing of 4px or 0.25rem
const TodaySpacing(4) - tdsSpace2 → const TodaySpacing
-
Spacing of 8px or 0.5rem
const TodaySpacing(8) - tdsSpace3 → const TodaySpacing
-
Spacing of 12px or 0.75rem
const TodaySpacing(12) - tdsSpace4 → const TodaySpacing
-
Spacing of 16px or 1rem
const TodaySpacing(16) - tdsSpace5 → const TodaySpacing
-
Spacing of 20px or 1.25rem
const TodaySpacing(20) - tdsSpace6 → const TodaySpacing
-
Spacing of 24px or 1.5rem
const TodaySpacing(24) - tdsSpace7 → const TodaySpacing
-
Spacing of 32px or 2rem
const TodaySpacing(32) - tdsSpace8 → const TodaySpacing
-
Spacing of 40px or 2.5rem
const TodaySpacing(40) - tdsSpace9 → const TodaySpacing
-
Spacing of 48px or 3rem
const TodaySpacing(48) - tdsSpace10 → const TodaySpacing
-
Spacing of 64px or 4rem
const TodaySpacing(64) - tdsSpace11 → const TodaySpacing
-
Spacing of 80px or 5rem
const TodaySpacing(80) - tdsSpace12 → const TodaySpacing
-
Spacing of 96px or 6rem
const TodaySpacing(96) - tdsSpace13 → const TodaySpacing
-
Spacing of 128px or 8rem
const TodaySpacing(128)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spacing → double
-
Get spacing size from TodaySpacing
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
TodaySpacing> - A constant List of the values in this enum, in order of their declaration.