TodayTextColor enum
Today's text colors
Values
- fullWhite → const TodayTextColor
-
Color #FFFFFF or rgba(255, 255, 255, 1)
const TodayTextColor(Color.fromRGBO(255, 255, 255, 1)) - white → const TodayTextColor
-
Color #FCFCFC or rgba(252, 252, 252, 1)
const TodayTextColor(Color.fromRGBO(252, 252, 252, 1)) - eerieBlack → const TodayTextColor
-
Color #171717 or rgba(23, 23, 23, 1)
const TodayTextColor(Color.fromRGBO(23, 23, 23, 1)) - pigmentGreen → const TodayTextColor
-
Color #16A34A or rgba(22, 163, 74, 1)
const TodayTextColor(Color.fromRGBO(22, 163, 74, 1)) - silver → const TodayTextColor
-
Color #A3A3A3 or rgba(163, 163, 163, 1)
const TodayTextColor(Color.fromRGBO(163, 163, 163, 1)) - frenchGray → const TodayTextColor
-
Color #C7D1DB or rgba(199, 209, 219, 1)
const TodayTextColor(Color.fromRGBO(199, 209, 219, 1)) - battleshipGray → const TodayTextColor
-
Color #8F8F8F or rgba(143, 143, 143, 1)
const TodayTextColor(Color.fromRGBO(143, 143, 143, 1)) - dimGray → const TodayTextColor
-
Color ##6F6F6F or rgba(111, 111, 111, 1)
const TodayTextColor(Color.fromRGBO(111, 111, 111, 1)) - cornflowerBlue → const TodayTextColor
-
Color #579DFF or rgba(87, 157, 255, 1)
const TodayTextColor(Color.fromRGBO(87, 157, 255, 1)) - cadetGray → const TodayTextColor
-
Color #9FADBC or rgba(159, 173, 188, 1)
const TodayTextColor(Color.fromRGBO(159, 173, 188, 1))
Properties
- color → Color
-
Color from TodayTextColor
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
TodayTextColor> - A constant List of the values in this enum, in order of their declaration.