TodayTextStyle enum

Today's text styles

Inheritance
Available extensions

Values

tdsFontXLargeHeavy → const TodayTextStyle
tdsFontXLargePlus → const TodayTextStyle

Font of 24px, 32px line height, weight 500, -0.47px letter spacing

tdsFontLargeHeavy → const TodayTextStyle

Font of 20px, 28px line height, weight 600, -0.33px letter spacing

tdsFontLargePlus → const TodayTextStyle

Font of 20px, 28px line height, weight 500, -0.33px letter spacing

tdsFontMediumHeavy → const TodayTextStyle

Font of 16px, 24px line height, weight 600, -0.18px letter spacing

tdsFontMediumPlus → const TodayTextStyle

Font of 16px, 24px line height, weight 500, -0.18px letter spacing

tdsFontMedium → const TodayTextStyle

Font of 16px, 24px line height, weight 400, -0.18px letter spacing

tdsFontRegularHeavy → const TodayTextStyle

Font of 14px, 20px line height, weight 600, -0.09px letter spacing

tdsFontRegularPlus → const TodayTextStyle

Font of 14px, 20px line height, weight 500, -0.09px letter spacing

tdsFontRegular → const TodayTextStyle

Font of 14px, 20px line height, weight 400, -0.09px letter spacing

tdsFontSmallHeavy → const TodayTextStyle

Font of 12px, 16px line height, weight 600, 0.01px letter spacing

tdsFontSmallPlus → const TodayTextStyle

Font of 12px, 16px line height, weight 500, 0.01px letter spacing

tdsFontSmall → const TodayTextStyle

Font of 12px, 16px line height, weight 400, 0.01px letter spacing

tdsFontMiniHeavy → const TodayTextStyle

Font of 11px, 12px line height, weight 600, 0.05px letter spacing

tdsFontMiniPlus → const TodayTextStyle

Font of 11px, 12px line height, weight 500, 0.05px letter spacing

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getTodayTextStyle({TodayTextColor color = TodayTextColor.eerieBlack, Color? rawColor, TextDecoration? decoration, TextDecorationStyle? decorationStyle, TextBaseline? textBaseline}) TextStyle

Available on TodayTextStyle, provided by the TodayTextStyleExtension extension

Get TextStyle from TodayTextStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TodayTextStyle>
A constant List of the values in this enum, in order of their declaration.